@@ -1,7 +1,7 @@
 """Symlinks"""
 
-from machineconfig.utils.path_reduced import PathExtended as PathExtended
-# from machineconfig.utils.utils import display_options
+from machineconfig.utils.path_extended import PathExtended as PathExtended
+# from machineconfig.utils.utils import choose_from_options
 
 
 def main():
@@ -22,7 +22,7 @@ def main():
 🎯 Target: {target}
 {"=" * 150}
 """)
-    print('🔗 Finished creating symlink.')
+    print("🔗 Finished creating symlink.")
 
 
 if __name__ == "__main__":
