@@ -1,15 +1,17 @@
 """package manager"""
 
-from machineconfig.utils.installer_utils.installer_abc import LINUX_INSTALL_PATH, CATEGORY
+from machineconfig.utils.installer_utils.installer_abc import check_if_installed_already, parse_apps_installer_linux, parse_apps_installer_windows
+
 from machineconfig.utils.installer_utils.installer_class import Installer
+from machineconfig.utils.schemas.installer.installer_types import InstallerData, InstallerDataFiles, get_normalized_arch, get_os_name, OPERATING_SYSTEMS, CPU_ARCHITECTURES
+from machineconfig.jobs.installer.package_groups import PACKAGE_GROUPS, PACKAGE_GROUP2NAMES
 from rich.console import Console
-from rich.panel import Panel  # Added import
+from rich.panel import Panel
 
-from machineconfig.utils.path_reduced import PathExtended as PathExtended
-from machineconfig.utils.source_of_truth import INSTALL_VERSION_ROOT
-from machineconfig.utils.utils2 import read_json
+from machineconfig.utils.path_extended import PathExtended as PathExtended
+from machineconfig.utils.source_of_truth import INSTALL_VERSION_ROOT, LINUX_INSTALL_PATH, LIBRARY_ROOT
+from machineconfig.utils.io import read_json
 
-# from dataclasses import dataclass
 from typing import Any
 import platform
 from joblib import Parallel, delayed
@@ -18,25 +20,28 @@ from joblib import Parallel, delayed
 def check_latest():
     console = Console()  # Added console initialization
     console.print(Panel("🔍  CHECKING FOR LATEST VERSIONS", title="Status", expand=False))  # Replaced print with Panel
-    installers = get_installers(system=platform.system(), dev=False)
-    # installers += get_installers(system=platform.system(), dev=True)
+    installers = get_installers(os=get_os_name(), arch=get_normalized_arch(), which_cats=["ESSENTIAL"])
     installers_github = []
     for inst__ in installers:
-        if "ntop" in inst__.name:
-            print(f"⏭️  Skipping {inst__.name} (ntop)")
+        app_name = inst__["appName"]
+        repo_url = inst__["repoURL"]
+        if "ntop" in app_name:
+            print(f"⏭️  Skipping {app_name} (ntop)")
             continue
-        if "github" not in inst__.repo_url:
-            print(f"⏭️  Skipping {inst__.name} (not a GitHub release)")
+        if "github" not in repo_url:
+            print(f"⏭️  Skipping {app_name} (not a GitHub release)")
             continue
         installers_github.append(inst__)
 
     print(f"\n🔍 Checking {len(installers_github)} GitHub-based installers...\n")
 
     def func(inst: Installer):
-        print(f"🔎 Checking {inst.exe_name}...")
-        _release_url, version_to_be_installed = inst.get_github_release(repo_url=inst.repo_url, version=None)
-        verdict, current_ver, new_ver = inst.check_if_installed_already(exe_name=inst.exe_name, version=version_to_be_installed, use_cache=False)
-        return inst.exe_name, verdict, current_ver, new_ver
+        exe_name = inst.installer_data.get("exeName", "unknown")
+        repo_url = inst.installer_data.get("repoURL", "")
+        print(f"🔎 Checking {exe_name}...")
+        _release_url, version_to_be_installed = inst.get_github_release(repo_url=repo_url, version=None)
+        verdict, current_ver, new_ver = check_if_installed_already(exe_name=exe_name, version=version_to_be_installed, use_cache=False)
+        return exe_name, verdict, current_ver, new_ver
 
     print("\n⏳ Processing installers...\n")
     res = [func(inst) for inst in installers_github]
@@ -88,86 +93,56 @@ def get_installed_cli_apps():
     return apps
 
 
-def get_installers(system: str, dev: bool) -> list[Installer]:
+def get_installers(os: OPERATING_SYSTEMS, arch: CPU_ARCHITECTURES, which_cats: list[PACKAGE_GROUPS]) -> list[InstallerData]:
     print(f"\n{'=' * 80}\n🔍 LOADING INSTALLER CONFIGURATIONS 🔍\n{'=' * 80}")
-    res_all = get_all_dicts(system=system)
-    if not dev:
-        print("ℹ️  Excluding development installers...")
-        del res_all["CUSTOM_DEV"]
-        del res_all["OS_SPECIFIC_DEV"]
-        del res_all["OS_GENERIC_DEV"]
-    res_final = {}
-    for _k, v in res_all.items():
-        res_final.update(v)
-    print(f"✅ Loaded {len(res_final)} installer configurations\n{'=' * 80}")
-    return [Installer.from_dict(d=vd, name=k) for k, vd in res_final.items()]
+    res_all = get_all_installer_data_files()
+    acceptable_apps_names: list[str] = []
+    for cat in which_cats:
+        acceptable_apps_names += PACKAGE_GROUP2NAMES[cat]
+    all_installers: list[InstallerData] = []
+    for installer_data in res_all:
+        if installer_data["appName"] in acceptable_apps_names:
+            if installer_data["fileNamePattern"][arch][os] is None:
+                continue
+            all_installers.append(installer_data)
+    print(f"✅ Loaded {len(all_installers)} installer configurations\n{'=' * 80}")
+    return all_installers
 
 
-def get_all_dicts(system: str) -> dict[CATEGORY, dict[str, dict[str, Any]]]:
+def get_all_installer_data_files() -> list[InstallerData]:
     print(f"\n{'=' * 80}\n📂 LOADING CONFIGURATION FILES 📂\n{'=' * 80}")
-
-    print(f"🔍 Importing OS-specific installers for {system}...")
-    if system == "Windows":
-        import machineconfig.jobs.python_windows_installers as os_specific_installer
-    else:
-        import machineconfig.jobs.python_linux_installers as os_specific_installer
-
-    print("🔍 Importing generic installers...")
-    import machineconfig.jobs.python_generic_installers as generic_installer
-
-    path_os_specific = PathExtended(os_specific_installer.__file__).parent
-    path_os_generic = PathExtended(generic_installer.__file__).parent
-
-    path_os_specific_dev = path_os_specific.joinpath("dev")
-    path_os_generic_dev = path_os_generic.joinpath("dev")
-
+    import machineconfig.jobs.installer as module
+    from pathlib import Path
     print("📂 Loading configuration files...")
-    res_final: dict[CATEGORY, dict[str, dict[str, Any]]] = {}
-    print(f"""📄 Loading OS-specific config from: {path_os_specific.joinpath("config.json")}""")
-    res_final["OS_SPECIFIC"] = read_json(path=path_os_specific.joinpath("config.json"))
-
-    print(f"""📄 Loading OS-generic config from: {path_os_generic.joinpath("config.json")}""")
-    res_final["OS_GENERIC"] = read_json(path=path_os_generic.joinpath("config.json"))
-
-    print(f"""📄 Loading OS-specific dev config from: {path_os_specific_dev.joinpath("config.json")}""")
-    res_final["OS_SPECIFIC_DEV"] = read_json(path=path_os_specific_dev.joinpath("config.json"))
-
-    print(f"""📄 Loading OS-generic dev config from: {path_os_generic_dev.joinpath("config.json")}""")
-    res_final["OS_GENERIC_DEV"] = read_json(path=path_os_generic_dev.joinpath("config.json"))
-
-    path_custom_installer = path_os_generic.with_name("python_custom_installers")
-    path_custom_installer_dev = path_custom_installer.joinpath("dev")
-
-    print(f"🔍 Loading custom installers from: {path_custom_installer}")
-    import runpy
-
-    res_custom: dict[str, dict[str, Any]] = {}
-    for item in path_custom_installer.search("*.py", r=False, not_in=["__init__"]):
-        try:
-            print(f"📄 Loading custom installer: {item.name}")
-            config_dict = runpy.run_path(str(item), run_name=None)["config_dict"]
-            res_custom[item.stem] = config_dict
-        except Exception as ex:
-            print(f"❌ Failed to load {item}: {ex}")
-
-    print(f"🔍 Loading custom dev installers from: {path_custom_installer_dev}")
-    res_custom_dev: dict[str, dict[str, Any]] = {}
-    for item in path_custom_installer_dev.search("*.py", r=False, not_in=["__init__"]):
-        try:
-            print(f"📄 Loading custom dev installer: {item.name}")
-            config_dict = runpy.run_path(str(item), run_name=None)["config_dict"]
-            res_custom_dev[item.stem] = config_dict
-        except Exception as ex:
-            print(f"❌ Failed to load {item}: {ex}")
-
-    res_final["CUSTOM"] = res_custom
-    res_final["CUSTOM_DEV"] = res_custom_dev
-
-    print(f"✅ Configuration loading complete:\n - OS_SPECIFIC: {len(res_final['OS_SPECIFIC'])} items\n - OS_GENERIC: {len(res_final['OS_GENERIC'])} items\n - CUSTOM: {len(res_final['CUSTOM'])} items\n{'=' * 80}")
+    res_raw: InstallerDataFiles = read_json(Path(module.__file__).parent.joinpath("installer_data.json"))
+    res_final: list[InstallerData] = res_raw["installers"]
+    print(f"Loaded: {len(res_final)} installer categories")
     return res_final
 
 
-def install_all(installers: list[Installer], safe: bool = False, jobs: int = 10, fresh: bool = False):
+def get_installers_system_groups():
+    res_final: list[InstallerData] = []
+    from platform import system
+    if system() == "Windows":
+        options_system = parse_apps_installer_windows(LIBRARY_ROOT.joinpath("setup_windows/apps.ps1").read_text(encoding="utf-8"))
+    elif system() == "Linux" or system() == "Darwin":
+        options_system = parse_apps_installer_linux(LIBRARY_ROOT.joinpath("setup_linux/apps.sh").read_text(encoding="utf-8"))
+    else:
+        raise NotImplementedError(f"❌ System {system()} not supported")
+    os_name = get_os_name()
+    for group_name, (docs, script) in options_system.items():
+        item: InstallerData = {
+            "appName": group_name,
+            "doc": docs,
+            "repoURL": "CMD",
+            "fileNamePattern": {
+                "amd64": {os_name: script,},
+                "arm64": {os_name: script,},}}
+        res_final.append(item)  
+    return res_final
+
+
+def install_all(installers_data: list[InstallerData], safe: bool = False, jobs: int = 10, fresh: bool = False):
     print(f"\n{'=' * 80}\n🚀 BULK INSTALLATION PROCESS 🚀\n{'=' * 80}")
     if fresh:
         print("🧹 Fresh install requested - clearing version cache...")
@@ -200,14 +175,14 @@ def install_all(installers: list[Installer], safe: bool = False, jobs: int = 10,
         # print(f"✅ Safe installation completed\n{'='*80}")
         # return None
 
-    print(f"🚀 Starting installation of {len(installers)} packages...")
+    print(f"🚀 Starting installation of {len(installers_data)} packages...")
     print(f"\n{'=' * 80}\n📦 INSTALLING FIRST PACKAGE 📦\n{'=' * 80}")
-    installers[0].install(version=None)
-    installers_remaining = installers[1:]
+    Installer(installers_data[0]).install(version=None)
+    installers_remaining = installers_data[1:]
     print(f"\n{'=' * 80}\n📦 INSTALLING REMAINING PACKAGES 📦\n{'=' * 80}")
 
     # Use joblib for parallel processing of remaining installers
-    res = Parallel(n_jobs=jobs)(delayed(lambda x: x.install_robust(version=None))(installer) for installer in installers_remaining)
+    res = Parallel(n_jobs=jobs)(delayed(lambda x: Installer(x).install_robust(version=None))(installer) for installer in installers_remaining)
 
     console = Console()
 
@@ -237,5 +212,4 @@ def install_all(installers: list[Installer], safe: bool = False, jobs: int = 10,
     print("\n" * 2)
 
 
-if __name__ == "__main__":
-    pass
+
