@@ -3,8 +3,8 @@ import os
 from dataclasses import dataclass
 import rich.console
 from machineconfig.utils.terminal import Terminal, Response, MACHINE
-from machineconfig.utils.path_reduced import PathExtended, PLike, OPLike
-from machineconfig.utils.utils2 import pprint
+from machineconfig.utils.path_extended import PathExtended, PLike, OPLike
+from machineconfig.utils.accessories import pprint
 # from machineconfig.utils.ve import get_ve_activate_line
 
 
@@ -116,13 +116,29 @@ class SSH:  # inferior alternative: https://github.com/fabric/fabric
             print(f"""⚠️  WARNING: Failed to open SFTP connection to {hostname}.
    Error Details: {err}\nData transfer may be affected!""")
 
-        def view_bar(slf: Any, a: Any, b: Any):
-            slf.total = int(b)
-            slf.update(int(a - slf.n))  # update pbar with increment
+        from rich.progress import Progress, SpinnerColumn, TextColumn, BarColumn, FileSizeColumn, TransferSpeedColumn
 
-        from tqdm import tqdm
+        class RichProgressWrapper:
+            def __init__(self, **kwargs: Any):
+                self.kwargs = kwargs
+                self.progress: Optional[Progress] = None
+                self.task: Optional[Any] = None
 
-        self.tqdm_wrap = type("TqdmWrap", (tqdm,), {"view_bar": view_bar})
+            def __enter__(self) -> "RichProgressWrapper":
+                self.progress = Progress(SpinnerColumn(), TextColumn("[bold blue]{task.description}"), BarColumn(), FileSizeColumn(), TransferSpeedColumn())
+                self.progress.start()
+                self.task = self.progress.add_task("Transferring...", total=0)
+                return self
+
+            def __exit__(self, exc_type: Any, exc_val: Any, exc_tb: Any) -> None:
+                if self.progress:
+                    self.progress.stop()
+
+            def view_bar(self, transferred: int, total: int) -> None:
+                if self.progress and self.task is not None:
+                    self.progress.update(self.task, completed=transferred, total=total)
+
+        self.tqdm_wrap = RichProgressWrapper
         self._local_distro: Optional[str] = None
         self._remote_distro: Optional[str] = None
         self._remote_machine: Optional[MACHINE] = None
@@ -201,7 +217,11 @@ class SSH:  # inferior alternative: https://github.com/fabric/fabric
         assert '"' not in cmd, 'Avoid using `"` in your command. I dont know how to handle this when passing is as command to python in pwsh command.'
         if not return_obj:
             return self.run(
-                cmd=f"""uv run --no-dev --project $HOME/code/machineconfig -c "{Terminal.get_header(wdir=None, toolbox=True)}{cmd}\n""" + '"', desc=desc or f"run_py on {self.get_remote_repr()}", verbose=verbose, strict_err=strict_err, strict_returncode=strict_returncode
+                cmd=f"""uv run --no-dev --project $HOME/code/machineconfig -c "{Terminal.get_header(wdir=None, toolbox=True)}{cmd}\n""" + '"',
+                desc=desc or f"run_py on {self.get_remote_repr()}",
+                verbose=verbose,
+                strict_err=strict_err,
+                strict_returncode=strict_returncode,
             )
         assert "obj=" in cmd, "The command sent to run_py must have `obj=` statement if return_obj is set to True"
         source_file = self.run_py(f"""{cmd}\npath = Save.pickle(obj=obj, path=P.tmpfile(suffix='.pkl'))\nprint(path)""", desc=desc, verbose=verbose, strict_err=True, strict_returncode=True).op.split("\n")[-1]
